@@ -371,7 +371,7 @@ class RateVideoDialog(QDialog, Ui_RateVideoDialog):
     """
     Dialog enabling the user to add a rating to a video.
     """
-    def __init__(self, parent, videoID):
+    def __init__(self, parent, videoId):
         """
         Constructor
         """
@@ -382,7 +382,7 @@ class RateVideoDialog(QDialog, Ui_RateVideoDialog):
             self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
         except:
             pass
-        self.videoID = videoID
+        self.videoId = videoId
         for num in range(5):
             item = QListWidgetItem()
             ratingLabel = QLabel()
@@ -399,9 +399,9 @@ class RateVideoDialog(QDialog, Ui_RateVideoDialog):
         """
         rating = self.ratingListWidget.row(item) + 1
         try:
-            youtubeservice.YouTubeDataService.addRating(rating, self.videoID)
+            youtubeservice.YouTubeDataService.addRating(rating, self.videoId)
             QMaemo5InformationBox.information(self, "You rated this video \'%s stars\'" % unicode(rating)) 
-            self.close()
+            self.accept()
         except:
             QMaemo5InformationBox.information(self, "Unable to add rating") 
 
