@@ -13,6 +13,7 @@ from Ui_myaccountwindow import Ui_MyAccountWindow
 import cutetubewindows
 import cutetubedialogs
 import youtubeservice
+from cutetubeconfig import YouTubeAPISettings
 
 class MyAccountWindow(QMainWindow, Ui_MyAccountWindow):
     """
@@ -46,7 +47,7 @@ class MyAccountWindow(QMainWindow, Ui_MyAccountWindow):
         if taskQueueLength > 0:
             self.actionDownloads.setVisible(True)
             self.actionDownloads.setText("Downloads (%s videos)" % unicode(taskQueueLength))
-        if len(youtubeservice.YouTubeDataService.userDict) <= 1:
+        if len(YouTubeAPISettings.userDict) <= 1:
             self.actionSwitchAccount.setVisible(False)
         self.show()
         
