@@ -60,19 +60,19 @@ class YouTubeDataService(object):
             YouTubeDataService.currentUser = username
         
     @staticmethod
-    def addComment(comment, videoID):
+    def addComment(comment, videoId):
         """
         Adds a comment to the video argument's comment feed.
         """
-        videoEntry = YouTubeDataService.ytService.GetYouTubeVideoEntry(uri = videoID)
+        videoEntry = YouTubeDataService.ytService.GetYouTubeVideoEntry(uri = videoId)
         YouTubeDataService.ytService.AddComment(unicode(comment), videoEntry) 
 
     @staticmethod
-    def addRating(rating, videoID):
+    def addRating(rating, videoId):
         """
         Adds a rating to the video argument.
         """
-        videoEntry = YouTubeDataService.ytService.GetYouTubeVideoEntry(uri = videoID)
+        videoEntry = YouTubeDataService.ytService.GetYouTubeVideoEntry(uri = videoId)
         YouTubeDataService.ytService.AddRating(rating, videoEntry)
     
     @staticmethod
